@@ -42,7 +42,7 @@ enum
 {
   PROP_0,
 
-  PROP_TYPE,
+  PROP_TYPE
 };
 
 static void		gconf_editor_window_set_property	(GObject          *object,
@@ -70,15 +70,13 @@ gconf_editor_window_popup_error_dialog (GtkWindow   *parent,
 	dialog = gtk_message_dialog_new (parent,
 					 GTK_DIALOG_DESTROY_WITH_PARENT,
 					 GTK_MESSAGE_ERROR,
-					 GTK_BUTTONS_CLOSE,
+					 GTK_BUTTONS_OK,
 					 message,
 					 error->message);
 	g_error_free (error);
 
-	g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-
-	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_widget_show (dialog);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 }
 
 static void
@@ -96,13 +94,22 @@ gconf_editor_window_go_to (GConfEditorWindow *window,
 	gint depth;
 	gint i, nchildren;
 	char *key;
-
+	gboolean dir_exists;
+	GError *error = NULL;
+	
 	g_return_if_fail (location != NULL);
-
-	if (!gconf_client_get (window->client, location, NULL) && 
-	    !gconf_client_dir_exists (window->client, location, NULL))
+		
+	dir_exists = gconf_client_dir_exists (window->client, location, &error);
+	
+	if (error != NULL) {
+    		gconf_editor_window_popup_error_dialog (GTK_WINDOW (window),"%s", error);
+        	return;
+	}
+	
+	if (!gconf_client_get (window->client, location, NULL) && !dir_exists)
 		return;
-
+	
+	
 	child_path = gconf_tree_model_get_tree_path_from_gconf_path (
 				GCONF_TREE_MODEL (window->tree_model), location);
 	if (!child_path)
@@ -137,7 +144,7 @@ gconf_editor_window_go_to (GConfEditorWindow *window,
 	gtk_tree_path_free (path);
 
 	/* check for key name in the list model */
-	key = rindex (location, '/');
+	key = strrchr (location, '/');
 	if (!key || strlen (key) < 2)
 		return;
 	key++;
@@ -392,7 +399,7 @@ gconf_editor_window_about_window (GtkAction *action, GtkWidget *callback_data)
 		"Shaun McCance <shaunm@gnome.org>",
 		NULL
 	};
-	const gchar *translator_credits = _("translator_credits");
+	const gchar *translator_credits = _("translator-credits");
 
 	gtk_show_about_dialog (GTK_WINDOW (callback_data),
 			      "version", VERSION,
@@ -400,7 +407,7 @@ gconf_editor_window_about_window (GtkAction *action, GtkWidget *callback_data)
 			      "comments", _("An editor for the GConf configuration system."),
 			      "authors", authors,
 			      "documenters", documenters,
-			      "translator_credits", strcmp(translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+			      "translator_credits", strcmp(translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
 			      "logo_icon_name", "gconf-editor",
 			      NULL);
 }	
@@ -752,7 +759,7 @@ static GtkActionEntry entries[] = {
 	  G_CALLBACK (gconf_editor_popup_window_new_key) },
 	{ "EditKey", NULL, N_("_Edit Key..."), NULL, N_("Edit the selected key"),
 	  G_CALLBACK (gconf_editor_popup_window_edit_key) },
-	{ "UnsetKey", GTK_STOCK_DELETE, N_("_Unset Key..."), NULL, N_("Unset the selected key"),
+	{ "UnsetKey", GTK_STOCK_DELETE, N_("_Unset Key"), NULL, N_("Unset the selected key"),
 	  G_CALLBACK (gconf_editor_popup_window_unset_key) },
 	{ "DefaultKey", NULL, N_("Set as _Default"), NULL, N_("Set the selected key to be the default"),
 	  G_CALLBACK (gconf_editor_popup_window_set_as_default) },
@@ -838,10 +845,10 @@ gconf_editor_window_selection_changed (GtkTreeSelection *selection, GConfEditorW
 
 	switch (window->type) {
 	case GCONF_EDITOR_WINDOW_TYPE_DEFAULTS:
-		base_title = _("Configuration Editor (Default Settings)");
+		base_title = _("Configuration Editor (Default settings)");
 		break;
 	case GCONF_EDITOR_WINDOW_TYPE_MANDATORY:
-		base_title = _("Configuration Editor (Mandatory Settings)");
+		base_title = _("Configuration Editor (Mandatory settings)");
 		break;
 	default:
 		base_title = _("Configuration Editor");
@@ -950,7 +957,7 @@ gconf_editor_gconf_value_changed (GConfCellRenderer *cell, const gchar *path_str
 		gconf_add_recent_key (window, key);
 	}
 
-	g_free (value);
+	gconf_value_free (value);
 	g_free (key);
 	gtk_tree_path_free (path);
 }
@@ -1279,46 +1286,33 @@ gconf_editor_window_expand_first (GConfEditorWindow *window)
 static GConfClient*
 gconf_editor_window_get_client (int type)
 {
-	static GConfClient *defaults_client = NULL;
-	static GConfClient *mandatory_client = NULL;
-
 	GConfEngine *engine;
 	GConfClient *client = NULL;
-        GError *error = NULL;
+	GError *error = NULL;
 
 	switch (type) {
 	case GCONF_EDITOR_WINDOW_TYPE_NORMAL:
 		client = gconf_client_get_default ();
 		break;
 	case GCONF_EDITOR_WINDOW_TYPE_DEFAULTS:
-		if (defaults_client != NULL) {
-			client = defaults_client;
-			g_object_ref (defaults_client);
-		} else {
-			engine = gconf_engine_get_for_address (GCONF_DEFAULTS_SOURCE, &error);
-			if (error) {
-				gconf_editor_window_popup_error_dialog (NULL,
-				_("Cannot create GConf engine. Error was:\n%s"), error);
-				return NULL;
-			}
-			client = gconf_client_get_for_engine (engine);
-			gconf_engine_unref (engine);
+		engine = gconf_engine_get_for_address (GCONF_DEFAULTS_SOURCE, &error);
+		if (error) {
+			gconf_editor_window_popup_error_dialog (NULL,
+			_("Cannot create GConf engine. Error was:\n%s"), error);
+			return NULL;
 		}
+		client = gconf_client_get_for_engine (engine);
+		gconf_engine_unref (engine);
 		break;
 	case GCONF_EDITOR_WINDOW_TYPE_MANDATORY:
-		if (mandatory_client != NULL) {
-			client = mandatory_client;
-			g_object_ref (mandatory_client);
-		} else {
-			engine = gconf_engine_get_for_address (GCONF_MANDATORY_SOURCE, &error);
-			if (error) {
-				gconf_editor_window_popup_error_dialog (NULL,
-				_("Cannot create GConf engine. Error was:\n%s"), error);
-				return NULL;
-			}
-			client = gconf_client_get_for_engine (engine);
-			gconf_engine_unref (engine);
+		engine = gconf_engine_get_for_address (GCONF_MANDATORY_SOURCE, &error);
+		if (error) {
+			gconf_editor_window_popup_error_dialog (NULL,
+			_("Cannot create GConf engine. Error was:\n%s"), error);
+			return NULL;
 		}
+		client = gconf_client_get_for_engine (engine);
+		gconf_engine_unref (engine);
 		break;
 	default:
 		g_assert_not_reached ();
