@@ -113,6 +113,7 @@ gconf_tree_model_search_iter_foreach (GtkTreeModel *model, GtkTreePath *path,
 				gedit_output_window_append_line (st->output_window, key, FALSE);
 				st->res++;
 				gconf_entry_free (entry);
+				continue;
 			}
 		}
 		gconf_entry_free (entry);
@@ -150,8 +151,9 @@ gconf_tree_model_build_match_list (GConfTreeModel *tree_model, GeditOutputWindow
 				gconf_tree_model_search_iter_foreach, st);
 
 	res = st->res;
-	g_free (st);
-
+#if 0
+	g_free (st); /* This causes invalid memory access according to valgrind */
+#endif		     /* FIXME: This introduces a small leak (24 bytes) */
 	return res;
 
 }
