@@ -22,8 +22,10 @@
 
 #include <gtk/gtkstock.h>
 
-#define GCONF_STOCK_ABOUT "gconf-about"
-#define GCONF_STOCK_BOOKMARK "gconf-bookmark"
+#define GCONF_STOCK_ABOUT 	"gconf-about"
+#define STOCK_BOOKMARK		"stock_bookmark"
+#define STOCK_ADD_BOOKMARK	"stock_add-bookmark"
+#define STOCK_EDIT_BOOKMARK	"stock_edit-bookmark"
 
 void gconf_stock_icons_register (void);
 
