@@ -21,6 +21,12 @@
 
 #include <string.h>
 
+enum {
+	GCONF_NOT_SET,
+	GCONF_CANNOT_EDIT,
+	GCONF_CAN_EDIT
+};
+ 
 GType
 gconf_value_get_type (void)
 {
@@ -74,13 +80,11 @@ gconf_value_type_to_string (GConfValueType value_type)
 GConfSchema *
 gconf_client_get_schema_for_key (GConfClient *client, const char *key)
 {
-	GConfEngine *engine;
 	GConfEntry *entry;
 	const char *schema_name;
 	GConfSchema *schema;
 
-	engine = gconf_engine_get_for_address (GCONF_DEFAULTS_SOURCE, NULL);
-	entry = gconf_engine_get_entry (engine, key, NULL, TRUE, NULL);
+	entry = gconf_client_get_entry (client, key, NULL, TRUE, NULL);
 	schema_name = gconf_entry_get_schema_name (entry);
 
 	if (schema_name == NULL)
@@ -90,3 +94,62 @@ gconf_client_get_schema_for_key (GConfClient *client, const char *key)
 
 	return schema;
 }
+
+static gboolean
+can_edit_source (const char *source)
+{
+	GConfEngine *engine;
+	GConfEntry  *entry;
+	GError      *error;
+	gboolean     retval;
+
+	if (!(engine = gconf_engine_get_for_address (source, NULL)))
+		return FALSE;
+
+	error = NULL;
+	entry = gconf_engine_get_entry (engine,
+					"/apps/gconf-editor/can_edit_source",
+					NULL,
+					FALSE,
+					&error);
+	if (error != NULL) {
+		g_assert (entry == NULL);
+		g_error_free (error);
+		gconf_engine_unref (engine);
+		return FALSE;
+	}
+
+	g_assert (entry != NULL);
+
+	retval = gconf_entry_get_is_writable (entry);
+
+	gconf_entry_unref (entry);
+	gconf_engine_unref (engine);
+
+	return retval;
+}
+
+gboolean
+gconf_util_can_edit_defaults (void)
+{
+	static int can_edit_defaults = GCONF_NOT_SET;
+
+	if (can_edit_defaults == GCONF_NOT_SET)
+		can_edit_defaults = can_edit_source (GCONF_DEFAULTS_SOURCE);
+
+	return can_edit_defaults;
+}
+
+gboolean
+gconf_util_can_edit_mandatory (void)
+{
+	static int can_edit_mandatory = GCONF_NOT_SET;
+
+	if (can_edit_mandatory == GCONF_NOT_SET)
+		can_edit_mandatory = can_edit_source (GCONF_MANDATORY_SOURCE);
+
+	return can_edit_mandatory;
+}
+
+	
+
